Class: Google::Apis::IdentitytoolkitV1::GoogleCloudIdentitytoolkitV1GetOobCodeResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/identitytoolkit_v1/classes.rb,
lib/google/apis/identitytoolkit_v1/representations.rb,
lib/google/apis/identitytoolkit_v1/representations.rb

Overview

Response message for GetOobCode.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudIdentitytoolkitV1GetOobCodeResponse

Returns a new instance of GoogleCloudIdentitytoolkitV1GetOobCodeResponse.



1018
1019
1020
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 1018

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#emailString

If return_oob_link is false in the request, the email address the verification was sent to. Corresponds to the JSON property email

Returns:

  • (String)


999
1000
1001
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 999

def email
  @email
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


1004
1005
1006
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 1004

def kind
  @kind
end

#oob_codeString

If return_oob_link is true in the request, the OOB code to send. Corresponds to the JSON property oobCode

Returns:

  • (String)


1009
1010
1011
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 1009

def oob_code
  @oob_code
end

If return_oob_link is true in the request, the OOB link to be sent to the user. This returns the constructed link including Firebase Dynamic Link related parameters. Corresponds to the JSON property oobLink

Returns:

  • (String)


1016
1017
1018
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 1016

def oob_link
  @oob_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1023
1024
1025
1026
1027
1028
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 1023

def update!(**args)
  @email = args[:email] if args.key?(:email)
  @kind = args[:kind] if args.key?(:kind)
  @oob_code = args[:oob_code] if args.key?(:oob_code)
  @oob_link = args[:oob_link] if args.key?(:oob_link)
end