Class: Google::Apis::IdentitytoolkitV1::GoogleCloudIdentitytoolkitV1SetAccountInfoRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/identitytoolkit_v1/classes.rb,
lib/google/apis/identitytoolkit_v1/representations.rb,
lib/google/apis/identitytoolkit_v1/representations.rb

Overview

Request message for SetAccountInfo.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudIdentitytoolkitV1SetAccountInfoRequest

Returns a new instance of GoogleCloudIdentitytoolkitV1SetAccountInfoRequest.



2027
2028
2029
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 2027

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#captcha_challengeString

Corresponds to the JSON property captchaChallenge

Returns:

  • (String)


1862
1863
1864
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 1862

def captcha_challenge
  @captcha_challenge
end

#captcha_responseString

The response from reCaptcha challenge. This is required when the system detects possible abuse activities. Corresponds to the JSON property captchaResponse

Returns:

  • (String)


1868
1869
1870
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 1868

def captcha_response
  @captcha_response
end

#created_atFixnum

The timestamp in milliseconds when the account was created. Corresponds to the JSON property createdAt

Returns:

  • (Fixnum)


1873
1874
1875
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 1873

def created_at
  @created_at
end

#custom_attributesString

JSON formatted custom attributes to be stored in the Identity Platform ID token. Specifying this field requires a Google OAuth 2.0 credential with proper permissions. Corresponds to the JSON property customAttributes

Returns:

  • (String)


1881
1882
1883
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 1881

def custom_attributes
  @custom_attributes
end

#delegated_project_numberFixnum

Corresponds to the JSON property delegatedProjectNumber

Returns:

  • (Fixnum)


1886
1887
1888
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 1886

def delegated_project_number
  @delegated_project_number
end

#delete_attributeArray<String>

Corresponds to the JSON property deleteAttribute

Returns:

  • (Array<String>)


1891
1892
1893
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 1891

def delete_attribute
  @delete_attribute
end

#delete_providerArray<String>

The Identity Providers to unlink from the user's account. Corresponds to the JSON property deleteProvider

Returns:

  • (Array<String>)


1896
1897
1898
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 1896

def delete_provider
  @delete_provider
end

#disable_userBoolean Also known as: disable_user?

If true, marks the account as disabled, meaning the user will no longer be able to sign-in. Corresponds to the JSON property disableUser

Returns:

  • (Boolean)


1902
1903
1904
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 1902

def disable_user
  @disable_user
end

#display_nameString

The user's new display name to be updated in the account's attributes. The length of the display name must be less than or equal to 256 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


1909
1910
1911
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 1909

def display_name
  @display_name
end

#emailString

The user's new email to be updated in the account's attributes. The length of email should be less than 256 characters and in the format of name@domain.tld . The email should also match the RFC 822 addr-spec production. If email enumeration protection is enabled, the email cannot be changed by the user without verifying the email first, but it can be changed by an administrator. Corresponds to the JSON property email

Returns:

  • (String)


1920
1921
1922
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 1920

def email
  @email
end

#email_verifiedBoolean Also known as: email_verified?

Whether the user's email has been verified. Specifying this field requires a Google OAuth 2.0 credential with proper permissions. Corresponds to the JSON property emailVerified

Returns:

  • (Boolean)


1927
1928
1929
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 1927

def email_verified
  @email_verified
end

#id_tokenString

A valid Identity Platform ID token. Required when attempting to change user- related information. Corresponds to the JSON property idToken

Returns:

  • (String)


1934
1935
1936
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 1934

def id_token
  @id_token
end

#instance_idString

Corresponds to the JSON property instanceId

Returns:

  • (String)


1939
1940
1941
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 1939

def instance_id
  @instance_id
end

#last_login_atFixnum

The timestamp in milliseconds when the account last logged in. Corresponds to the JSON property lastLoginAt

Returns:

  • (Fixnum)


1944
1945
1946
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 1944

def 
  @last_login_at
end

Information about the user as provided by various Identity Providers. Corresponds to the JSON property linkProviderUserInfo



1949
1950
1951
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 1949

def 
  @link_provider_user_info
end

#local_idString

The ID of the user. Specifying this field requires a Google OAuth 2.0 credential with proper permissions. For requests from end-users, an ID token should be passed instead. Corresponds to the JSON property localId

Returns:

  • (String)


1957
1958
1959
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 1957

def local_id
  @local_id
end

#mfaGoogle::Apis::IdentitytoolkitV1::GoogleCloudIdentitytoolkitV1MfaInfo

Multi-factor authentication related information. Corresponds to the JSON property mfa



1962
1963
1964
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 1962

def mfa
  @mfa
end

#oob_codeString

The out-of-band code to be applied on the user's account. The following out-of- band code types are supported: * VERIFY_EMAIL * RECOVER_EMAIL * REVERT_SECOND_FACTOR_ADDITION * VERIFY_AND_CHANGE_EMAIL Corresponds to the JSON property oobCode

Returns:

  • (String)


1969
1970
1971
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 1969

def oob_code
  @oob_code
end

#passwordString

The user's new password to be updated in the account's attributes. The password must be at least 6 characters long. Corresponds to the JSON property password

Returns:

  • (String)


1975
1976
1977
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 1975

def password
  @password
end

#phone_numberString

The phone number to be updated in the account's attributes. Corresponds to the JSON property phoneNumber

Returns:

  • (String)


1980
1981
1982
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 1980

def phone_number
  @phone_number
end

#photo_urlString

The user's new photo URL for the account's profile photo to be updated in the account's attributes. The length of the URL must be less than or equal to 2048 characters. Corresponds to the JSON property photoUrl

Returns:

  • (String)


1987
1988
1989
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 1987

def photo_url
  @photo_url
end

#providerArray<String>

The Identity Providers that the account should be associated with. Corresponds to the JSON property provider

Returns:

  • (Array<String>)


1992
1993
1994
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 1992

def provider
  @provider
end

#return_secure_tokenBoolean Also known as: return_secure_token?

Whether or not to return an ID and refresh token. Should always be true. Corresponds to the JSON property returnSecureToken

Returns:

  • (Boolean)


1997
1998
1999
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 1997

def return_secure_token
  @return_secure_token
end

#target_project_idString

The project ID for the project that the account belongs to. Specifying this field requires Google OAuth 2.0 credential with proper permissions. Requests from end users should pass an Identity Platform ID token instead. Corresponds to the JSON property targetProjectId

Returns:

  • (String)


2006
2007
2008
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 2006

def target_project_id
  @target_project_id
end

#tenant_idString

The tenant ID of the Identity Platform tenant that the account belongs to. Requests from end users should pass an Identity Platform ID token rather than setting this field. Corresponds to the JSON property tenantId

Returns:

  • (String)


2013
2014
2015
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 2013

def tenant_id
  @tenant_id
end

#upgrade_to_federated_loginBoolean Also known as: upgrade_to_federated_login?

Whether the account should be restricted to only using federated login. Corresponds to the JSON property upgradeToFederatedLogin

Returns:

  • (Boolean)


2018
2019
2020
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 2018

def 
  @upgrade_to_federated_login
end

#valid_sinceFixnum

Specifies the minimum timestamp in seconds for an Identity Platform ID token to be considered valid. Corresponds to the JSON property validSince

Returns:

  • (Fixnum)


2025
2026
2027
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 2025

def valid_since
  @valid_since
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2032
2033
2034
2035
2036
2037
2038
2039
2040
2041
2042
2043
2044
2045
2046
2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
2057
2058
2059
2060
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 2032

def update!(**args)
  @captcha_challenge = args[:captcha_challenge] if args.key?(:captcha_challenge)
  @captcha_response = args[:captcha_response] if args.key?(:captcha_response)
  @created_at = args[:created_at] if args.key?(:created_at)
  @custom_attributes = args[:custom_attributes] if args.key?(:custom_attributes)
  @delegated_project_number = args[:delegated_project_number] if args.key?(:delegated_project_number)
  @delete_attribute = args[:delete_attribute] if args.key?(:delete_attribute)
  @delete_provider = args[:delete_provider] if args.key?(:delete_provider)
  @disable_user = args[:disable_user] if args.key?(:disable_user)
  @display_name = args[:display_name] if args.key?(:display_name)
  @email = args[:email] if args.key?(:email)
  @email_verified = args[:email_verified] if args.key?(:email_verified)
  @id_token = args[:id_token] if args.key?(:id_token)
  @instance_id = args[:instance_id] if args.key?(:instance_id)
  @last_login_at = args[:last_login_at] if args.key?(:last_login_at)
  @link_provider_user_info = args[:link_provider_user_info] if args.key?(:link_provider_user_info)
  @local_id = args[:local_id] if args.key?(:local_id)
  @mfa = args[:mfa] if args.key?(:mfa)
  @oob_code = args[:oob_code] if args.key?(:oob_code)
  @password = args[:password] if args.key?(:password)
  @phone_number = args[:phone_number] if args.key?(:phone_number)
  @photo_url = args[:photo_url] if args.key?(:photo_url)
  @provider = args[:provider] if args.key?(:provider)
  @return_secure_token = args[:return_secure_token] if args.key?(:return_secure_token)
  @target_project_id = args[:target_project_id] if args.key?(:target_project_id)
  @tenant_id = args[:tenant_id] if args.key?(:tenant_id)
  @upgrade_to_federated_login = args[:upgrade_to_federated_login] if args.key?(:upgrade_to_federated_login)
  @valid_since = args[:valid_since] if args.key?(:valid_since)
end