Class: Google::Apis::IdentitytoolkitV1::GoogleCloudIdentitytoolkitV1UploadAccountRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/identitytoolkit_v1/classes.rb,
lib/google/apis/identitytoolkit_v1/representations.rb,
lib/google/apis/identitytoolkit_v1/representations.rb

Overview

Request message for UploadAccount.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudIdentitytoolkitV1UploadAccountRequest

Returns a new instance of GoogleCloudIdentitytoolkitV1UploadAccountRequest.



3630
3631
3632
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3630

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_overwriteBoolean Also known as: allow_overwrite?

Whether to overwrite an existing account in Identity Platform with a matching local_id in the request. If true, the existing account will be overwritten. If false, an error will be returned. Corresponds to the JSON property allowOverwrite

Returns:

  • (Boolean)


3524
3525
3526
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3524

def allow_overwrite
  @allow_overwrite
end

#argon2_parametersGoogle::Apis::IdentitytoolkitV1::GoogleCloudIdentitytoolkitV1Argon2Parameters

The parameters for Argon2 hashing algorithm. Corresponds to the JSON property argon2Parameters



3530
3531
3532
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3530

def argon2_parameters
  @argon2_parameters
end

#block_sizeFixnum

The block size parameter used by the STANDARD_SCRYPT hashing function. This parameter, along with parallelization and cpu_mem_cost help tune the resources needed to hash a password, and should be tuned as processor speeds and memory technologies advance. Corresponds to the JSON property blockSize

Returns:

  • (Fixnum)


3538
3539
3540
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3538

def block_size
  @block_size
end

#cpu_mem_costFixnum

The CPU memory cost parameter to be used by the STANDARD_SCRYPT hashing function. This parameter, along with block_size and cpu_mem_cost help tune the resources needed to hash a password, and should be tuned as processor speeds and memory technologies advance. Corresponds to the JSON property cpuMemCost

Returns:

  • (Fixnum)


3546
3547
3548
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3546

def cpu_mem_cost
  @cpu_mem_cost
end

#delegated_project_numberFixnum

Corresponds to the JSON property delegatedProjectNumber

Returns:

  • (Fixnum)


3551
3552
3553
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3551

def delegated_project_number
  @delegated_project_number
end

#dk_lenFixnum

The desired key length for the STANDARD_SCRYPT hashing function. Must be at least 1. Corresponds to the JSON property dkLen

Returns:

  • (Fixnum)


3557
3558
3559
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3557

def dk_len
  @dk_len
end

#hash_algorithmString

Required. The hashing function used to hash the account passwords. Must be one of the following: * HMAC_SHA256 * HMAC_SHA1 * HMAC_MD5 * SCRYPT * PBKDF_SHA1 * MD5 * HMAC_SHA512 * SHA1 * BCRYPT * PBKDF2_SHA256 * SHA256 * SHA512 * STANDARD_SCRYPT * ARGON2 Corresponds to the JSON property hashAlgorithm

Returns:

  • (String)


3565
3566
3567
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3565

def hash_algorithm
  @hash_algorithm
end

#memory_costFixnum

Memory cost for hash calculation. Only required when the hashing function is SCRYPT. Corresponds to the JSON property memoryCost

Returns:

  • (Fixnum)


3571
3572
3573
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3571

def memory_cost
  @memory_cost
end

#parallelizationFixnum

The parallelization cost parameter to be used by the STANDARD_SCRYPT hashing function. This parameter, along with block_size and cpu_mem_cost help tune the resources needed to hash a password, and should be tuned as processor speeds and memory technologies advance. Corresponds to the JSON property parallelization

Returns:

  • (Fixnum)


3579
3580
3581
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3579

def parallelization
  @parallelization
end

#password_hash_orderString

Corresponds to the JSON property passwordHashOrder

Returns:

  • (String)


3584
3585
3586
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3584

def password_hash_order
  @password_hash_order
end

#roundsFixnum

The number of rounds used for hash calculation. Only required for the following hashing functions: * MD5 * SHA1 * SHA256 * SHA512 * PBKDF_SHA1 * PBKDF2_SHA256 * SCRYPT Corresponds to the JSON property rounds

Returns:

  • (Fixnum)


3591
3592
3593
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3591

def rounds
  @rounds
end

#salt_separatorString

One or more bytes to be inserted between the salt and plain text password. For stronger security, this should be a single non-printable character. Corresponds to the JSON property saltSeparator NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


3598
3599
3600
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3598

def salt_separator
  @salt_separator
end

#sanity_checkBoolean Also known as: sanity_check?

If true, the service will do the following list of checks before an account is uploaded: * Duplicate emails * Duplicate federated IDs * Federated ID provider validation If the duplication exists within the list of accounts to be uploaded, it will prevent the entire list from being uploaded. If the email or federated ID is a duplicate of a user already within the project/tenant, the account will not be uploaded, but the rest of the accounts will be unaffected. If false, these checks will be skipped. Corresponds to the JSON property sanityCheck

Returns:

  • (Boolean)


3609
3610
3611
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3609

def sanity_check
  @sanity_check
end

#signer_keyString

The signer key used to hash the password. Required for the following hashing functions: * SCRYPT, * HMAC_MD5, * HMAC_SHA1, * HMAC_SHA256, * HMAC_SHA512 Corresponds to the JSON property signerKey NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


3617
3618
3619
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3617

def signer_key
  @signer_key
end

#tenant_idString

The ID of the Identity Platform tenant the account belongs to. Corresponds to the JSON property tenantId

Returns:

  • (String)


3622
3623
3624
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3622

def tenant_id
  @tenant_id
end

#usersArray<Google::Apis::IdentitytoolkitV1::GoogleCloudIdentitytoolkitV1UserInfo>

A list of accounts to upload. local_id is required for each user; everything else is optional. Corresponds to the JSON property users



3628
3629
3630
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3628

def users
  @users
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3635
3636
3637
3638
3639
3640
3641
3642
3643
3644
3645
3646
3647
3648
3649
3650
3651
3652
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3635

def update!(**args)
  @allow_overwrite = args[:allow_overwrite] if args.key?(:allow_overwrite)
  @argon2_parameters = args[:argon2_parameters] if args.key?(:argon2_parameters)
  @block_size = args[:block_size] if args.key?(:block_size)
  @cpu_mem_cost = args[:cpu_mem_cost] if args.key?(:cpu_mem_cost)
  @delegated_project_number = args[:delegated_project_number] if args.key?(:delegated_project_number)
  @dk_len = args[:dk_len] if args.key?(:dk_len)
  @hash_algorithm = args[:hash_algorithm] if args.key?(:hash_algorithm)
  @memory_cost = args[:memory_cost] if args.key?(:memory_cost)
  @parallelization = args[:parallelization] if args.key?(:parallelization)
  @password_hash_order = args[:password_hash_order] if args.key?(:password_hash_order)
  @rounds = args[:rounds] if args.key?(:rounds)
  @salt_separator = args[:salt_separator] if args.key?(:salt_separator)
  @sanity_check = args[:sanity_check] if args.key?(:sanity_check)
  @signer_key = args[:signer_key] if args.key?(:signer_key)
  @tenant_id = args[:tenant_id] if args.key?(:tenant_id)
  @users = args[:users] if args.key?(:users)
end