Class: Google::Apis::IdentitytoolkitV1::GoogleCloudIdentitytoolkitV1UserInfo
- Inherits:
-
Object
- Object
- Google::Apis::IdentitytoolkitV1::GoogleCloudIdentitytoolkitV1UserInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/identitytoolkit_v1/classes.rb,
lib/google/apis/identitytoolkit_v1/representations.rb,
lib/google/apis/identitytoolkit_v1/representations.rb
Overview
An Identity Platform account's information.
Instance Attribute Summary collapse
-
#created_at ⇒ Fixnum
The time, in milliseconds from epoch, when the account was created.
-
#custom_attributes ⇒ String
Custom claims to be added to any ID tokens minted for the account.
-
#custom_auth ⇒ Boolean
(also: #custom_auth?)
Output only.
-
#date_of_birth ⇒ String
Output only.
-
#disabled ⇒ Boolean
(also: #disabled?)
Whether the account is disabled.
-
#display_name ⇒ String
The display name of the account.
-
#email ⇒ String
The account's email address.
-
#email_link_signin ⇒ Boolean
(also: #email_link_signin?)
Output only.
-
#email_verified ⇒ Boolean
(also: #email_verified?)
Whether the account's email address has been verified.
-
#initial_email ⇒ String
The first email address associated with this account.
-
#language ⇒ String
Output only.
-
#last_login_at ⇒ Fixnum
The last time, in milliseconds from epoch, this account was logged into.
-
#last_refresh_at ⇒ String
Timestamp when an ID token was last minted for this account.
-
#local_id ⇒ String
Immutable.
-
#mfa_info ⇒ Array<Google::Apis::IdentitytoolkitV1::GoogleCloudIdentitytoolkitV1MfaEnrollment>
Information on which multi-factor authentication providers are enabled for this account.
-
#password_hash ⇒ String
The account's hashed password.
-
#password_updated_at ⇒ Float
The timestamp, in milliseconds from the epoch of 1970-01-01T00:00:00Z, when the account's password was last updated.
-
#phone_number ⇒ String
The account's phone number.
-
#photo_url ⇒ String
The URL of the account's profile photo.
-
#provider_user_info ⇒ Array<Google::Apis::IdentitytoolkitV1::GoogleCloudIdentitytoolkitV1ProviderUserInfo>
Information about the user as provided by various Identity Providers.
-
#raw_password ⇒ String
Input only.
-
#salt ⇒ String
The account's password salt.
-
#screen_name ⇒ String
Output only.
-
#tenant_id ⇒ String
ID of the tenant this account belongs to.
-
#time_zone ⇒ String
Output only.
-
#valid_since ⇒ Fixnum
Oldest timestamp, in seconds since epoch, that an ID token should be considered valid.
-
#version ⇒ Fixnum
The version of the account's password.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudIdentitytoolkitV1UserInfo
constructor
A new instance of GoogleCloudIdentitytoolkitV1UserInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudIdentitytoolkitV1UserInfo
Returns a new instance of GoogleCloudIdentitytoolkitV1UserInfo.
3850 3851 3852 |
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3850 def initialize(**args) update!(**args) end |
Instance Attribute Details
#created_at ⇒ Fixnum
The time, in milliseconds from epoch, when the account was created.
Corresponds to the JSON property createdAt
3687 3688 3689 |
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3687 def created_at @created_at end |
#custom_attributes ⇒ String
Custom claims to be added to any ID tokens minted for the account. Should be
at most 1,000 characters in length and in valid JSON format.
Corresponds to the JSON property customAttributes
3693 3694 3695 |
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3693 def custom_attributes @custom_attributes end |
#custom_auth ⇒ Boolean Also known as: custom_auth?
Output only. Whether this account has been authenticated using
SignInWithCustomToken.
Corresponds to the JSON property customAuth
3699 3700 3701 |
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3699 def custom_auth @custom_auth end |
#date_of_birth ⇒ String
Output only. The date of birth set for the account. This account attribute is
not used by Identity Platform. It is available for informational purposes only.
Corresponds to the JSON property dateOfBirth
3706 3707 3708 |
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3706 def date_of_birth @date_of_birth end |
#disabled ⇒ Boolean Also known as: disabled?
Whether the account is disabled. Disabled accounts are inaccessible except for
requests bearing a Google OAuth2 credential with proper permissions.
Corresponds to the JSON property disabled
3712 3713 3714 |
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3712 def disabled @disabled end |
#display_name ⇒ String
The display name of the account. This account attribute is not used by
Identity Platform. It is available for informational purposes only.
Corresponds to the JSON property displayName
3719 3720 3721 |
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3719 def display_name @display_name end |
#email ⇒ String
The account's email address. The length of the email should be less than 256
characters and in the format of name@domain.tld. The email should also match
the RFC 822 addr-spec.
Corresponds to the JSON property email
3726 3727 3728 |
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3726 def email @email end |
#email_link_signin ⇒ Boolean Also known as: email_link_signin?
Output only. Whether the account can authenticate with email link.
Corresponds to the JSON property emailLinkSignin
3731 3732 3733 |
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3731 def email_link_signin @email_link_signin end |
#email_verified ⇒ Boolean Also known as: email_verified?
Whether the account's email address has been verified.
Corresponds to the JSON property emailVerified
3737 3738 3739 |
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3737 def email_verified @email_verified end |
#initial_email ⇒ String
The first email address associated with this account. The account's initial
email cannot be changed once set and is used to recover access to this account
if lost via the RECOVER_EMAIL flow in GetOobCode. Should match the RFC 822 addr-spec.
Corresponds to the JSON property initialEmail
3746 3747 3748 |
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3746 def initial_email @initial_email end |
#language ⇒ String
Output only. The language preference of the account. This account attribute is
not used by Identity Platform. It is available for informational purposes only.
Corresponds to the JSON property language
3752 3753 3754 |
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3752 def language @language end |
#last_login_at ⇒ Fixnum
The last time, in milliseconds from epoch, this account was logged into.
Corresponds to the JSON property lastLoginAt
3757 3758 3759 |
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3757 def last_login_at @last_login_at end |
#last_refresh_at ⇒ String
Timestamp when an ID token was last minted for this account.
Corresponds to the JSON property lastRefreshAt
3762 3763 3764 |
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3762 def last_refresh_at @last_refresh_at end |
#local_id ⇒ String
Immutable. The unique ID of the account.
Corresponds to the JSON property localId
3767 3768 3769 |
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3767 def local_id @local_id end |
#mfa_info ⇒ Array<Google::Apis::IdentitytoolkitV1::GoogleCloudIdentitytoolkitV1MfaEnrollment>
Information on which multi-factor authentication providers are enabled for
this account.
Corresponds to the JSON property mfaInfo
3773 3774 3775 |
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3773 def mfa_info @mfa_info end |
#password_hash ⇒ String
The account's hashed password. Only accessible by requests bearing a Google
OAuth2 credential with proper permissions.
Corresponds to the JSON property passwordHash
NOTE: Values are automatically base64 encoded/decoded in the client library.
3781 3782 3783 |
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3781 def password_hash @password_hash end |
#password_updated_at ⇒ Float
The timestamp, in milliseconds from the epoch of 1970-01-01T00:00:00Z, when
the account's password was last updated.
Corresponds to the JSON property passwordUpdatedAt
3787 3788 3789 |
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3787 def password_updated_at @password_updated_at end |
#phone_number ⇒ String
The account's phone number.
Corresponds to the JSON property phoneNumber
3792 3793 3794 |
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3792 def phone_number @phone_number end |
#photo_url ⇒ String
The URL of the account's profile photo. This account attribute is not used by
Identity Platform. It is available for informational purposes only.
Corresponds to the JSON property photoUrl
3798 3799 3800 |
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3798 def photo_url @photo_url end |
#provider_user_info ⇒ Array<Google::Apis::IdentitytoolkitV1::GoogleCloudIdentitytoolkitV1ProviderUserInfo>
Information about the user as provided by various Identity Providers.
Corresponds to the JSON property providerUserInfo
3803 3804 3805 |
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3803 def provider_user_info @provider_user_info end |
#raw_password ⇒ String
Input only. Plain text password used to update a account's password. This
field is only ever used as input in a request. Identity Platform uses
cryptographically secure hashing when managing passwords and will never store
or transmit a user's password in plain text.
Corresponds to the JSON property rawPassword
3811 3812 3813 |
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3811 def raw_password @raw_password end |
#salt ⇒ String
The account's password salt. Only accessible by requests bearing a Google
OAuth2 credential with proper permissions.
Corresponds to the JSON property salt
NOTE: Values are automatically base64 encoded/decoded in the client library.
3818 3819 3820 |
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3818 def salt @salt end |
#screen_name ⇒ String
Output only. This account's screen name at Twitter or login name at GitHub.
Corresponds to the JSON property screenName
3823 3824 3825 |
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3823 def screen_name @screen_name end |
#tenant_id ⇒ String
ID of the tenant this account belongs to. Only set if this account belongs to
a tenant.
Corresponds to the JSON property tenantId
3829 3830 3831 |
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3829 def tenant_id @tenant_id end |
#time_zone ⇒ String
Output only. The time zone preference of the account. This account attribute
is not used by Identity Platform. It is available for informational purposes
only.
Corresponds to the JSON property timeZone
3836 3837 3838 |
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3836 def time_zone @time_zone end |
#valid_since ⇒ Fixnum
Oldest timestamp, in seconds since epoch, that an ID token should be
considered valid. All ID tokens issued before this time are considered invalid.
Corresponds to the JSON property validSince
3842 3843 3844 |
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3842 def valid_since @valid_since end |
#version ⇒ Fixnum
The version of the account's password. Only accessible by requests bearing a
Google OAuth2 credential with proper permissions.
Corresponds to the JSON property version
3848 3849 3850 |
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3848 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3855 3856 3857 3858 3859 3860 3861 3862 3863 3864 3865 3866 3867 3868 3869 3870 3871 3872 3873 3874 3875 3876 3877 3878 3879 3880 3881 3882 3883 |
# File 'lib/google/apis/identitytoolkit_v1/classes.rb', line 3855 def update!(**args) @created_at = args[:created_at] if args.key?(:created_at) @custom_attributes = args[:custom_attributes] if args.key?(:custom_attributes) @custom_auth = args[:custom_auth] if args.key?(:custom_auth) @date_of_birth = args[:date_of_birth] if args.key?(:date_of_birth) @disabled = args[:disabled] if args.key?(:disabled) @display_name = args[:display_name] if args.key?(:display_name) @email = args[:email] if args.key?(:email) @email_link_signin = args[:email_link_signin] if args.key?(:email_link_signin) @email_verified = args[:email_verified] if args.key?(:email_verified) @initial_email = args[:initial_email] if args.key?(:initial_email) @language = args[:language] if args.key?(:language) @last_login_at = args[:last_login_at] if args.key?(:last_login_at) @last_refresh_at = args[:last_refresh_at] if args.key?(:last_refresh_at) @local_id = args[:local_id] if args.key?(:local_id) @mfa_info = args[:mfa_info] if args.key?(:mfa_info) @password_hash = args[:password_hash] if args.key?(:password_hash) @password_updated_at = args[:password_updated_at] if args.key?(:password_updated_at) @phone_number = args[:phone_number] if args.key?(:phone_number) @photo_url = args[:photo_url] if args.key?(:photo_url) @provider_user_info = args[:provider_user_info] if args.key?(:provider_user_info) @raw_password = args[:raw_password] if args.key?(:raw_password) @salt = args[:salt] if args.key?(:salt) @screen_name = args[:screen_name] if args.key?(:screen_name) @tenant_id = args[:tenant_id] if args.key?(:tenant_id) @time_zone = args[:time_zone] if args.key?(:time_zone) @valid_since = args[:valid_since] if args.key?(:valid_since) @version = args[:version] if args.key?(:version) end |